@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 '''obexd mock template
 
 This creates the expected methods and properties of the object manager
@@ -62,7 +60,7 @@ def CreateSession(self, destination, args):
 
     The destination must be the address of the destination Bluetooth device.
     The given arguments must be a map from well-known keys to values,
-    containing at least the ‘Target’ key, whose value must be ‘PBAP’ (other
+    containing at least the `Target` key, whose value must be `PBAP` (other
     keys and values are accepted by the real daemon, but not by this mock
     daemon at the moment). If the target is missing or incorrect, an
     Unsupported error is returned on the bus.
@@ -160,7 +158,7 @@ def PullAll(self, target_file, filters):
     '''OBEX method to start a pull transfer of a phone book.
 
     This doesn't complete the transfer; code to mock up activating and
-    completing the transfer must be provided by the test driver, as it’s
+    completing the transfer must be provided by the test driver, as it is
     too complex and test-specific to put here.
 
     The target_file is the absolute path for a file which will have zero or
@@ -225,7 +223,7 @@ def PullAll(self, target_file, filters):
 
     # Emit a behind-the-scenes signal that a new transfer has been created.
     manager.EmitSignal(OBEX_MOCK_IFACE, 'TransferCreated', 'sa{sv}s',
-                       [transfer_path, filters, filename])
+                       [transfer_path, filters, str(filename)])
 
     return (transfer_path, props)
 
