@@ -1,5 +1,3 @@
-#!/usr/bin/python3
-
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
 # Software Foundation; either version 3 of the License, or (at your option) any
@@ -25,7 +23,6 @@ from pathlib import Path
 
 import dbus
 import dbus.mainloop.glib
-
 from gi.repository import GLib
 
 import dbusmock
@@ -116,7 +113,7 @@ assert args[1] == ['/foo']
 assert type(args[1]) == dbus.Array
 assert type(args[1][0]) == dbus.ObjectPath
 assert args[2] == 5
-assert args[3] == {repr(UNICODE)}
+assert args[3] == {UNICODE!r}
 ''')
         self.assertEqual(self.dbus_test.Do(-1, ['/foo'], 5, UNICODE), None)
 
@@ -1047,7 +1044,7 @@ class TestServiceAutostart(dbusmock.DBusTestCase):
         session_dir.mkdir()
 
         (system_dir / 'org.TestSystem.service').write_text(
-            '[D-BUS Service]\n' +
+            '[D-BUS Service]\n'
             'Name=org.TestSystem\n'
             'Exec=/usr/bin/python3 -c "import sys; from gi.repository import GLib, Gio; '
             '     Gio.bus_own_name(Gio.BusType.SYSTEM, \'org.TestSystem\', 0, None, None, lambda *args: sys.exit(0)); '
