@@ -1,6 +1,3 @@
-#!/usr/bin/python3
-# -*- coding: utf-8 -*-
-
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
 # Software Foundation; either version 3 of the License, or (at your option) any
@@ -25,7 +22,6 @@ from pathlib import Path
 
 import dbus
 import dbus.mainloop.glib
-
 from gi.repository import GLib
 
 import dbusmock
@@ -60,13 +56,13 @@ def _run_bluetoothctl(command):
     # Strip the prompt from the start of every line, then remove empty
     # lines.
     #
-    # The prompt looks like ‘[bluetooth]# ’, potentially containing command
+    # The prompt looks like `[bluetooth]# `, potentially containing command
     # line colour control codes. Split at the first space.
     #
-    # Sometimes we end up with the final line being ‘\x1b[K’ (partial
+    # Sometimes we end up with the final line being `\x1b[K` (partial
     # control code), which we need to ignore.
     def remove_prefix(line):
-        if line.startswith('[bluetooth]#') or line.startswith('\x1b'):
+        if line.startswith(('[bluetooth]#', '\x1b')):
             parts = line.split(' ', 1)
             try:
                 return parts[1].strip()
@@ -79,10 +75,7 @@ def _run_bluetoothctl(command):
     lines = filter(lambda line: line != '', lines)
 
     # Filter out the echoed commands. (bluetoothctl uses readline.)
-    lines = filter(lambda line: line not in ['list', command, 'quit'], lines)
-    lines = list(lines)
-
-    return lines
+    return list(filter(lambda line: line not in ['list', command, 'quit'], lines))
 
 
 @unittest.skipUnless(have_bluetoothctl, 'bluetoothctl not installed')
@@ -164,7 +157,7 @@ class TestBlueZ5(dbusmock.DBusTestCase):
         out = _run_bluetoothctl('devices')
         self.assertIn('Device ' + address + ' ' + alias, out)
 
-        # Check the device’s properties.
+        # Check the device's properties.
         out = '\n'.join(_run_bluetoothctl('info ' + address))
         self.assertIn('Device ' + address, out)
         self.assertIn('Name: ' + alias, out)
@@ -190,7 +183,7 @@ class TestBlueZ5(dbusmock.DBusTestCase):
         # Pair with the device.
         self.dbusmock_bluez.PairDevice(adapter_name, address, 5898764)
 
-        # Check the device’s properties.
+        # Check the device's properties.
         out = '\n'.join(_run_bluetoothctl('info ' + address))
         self.assertIn('Device ' + address, out)
         self.assertIn('Paired: yes', out)
@@ -250,16 +243,16 @@ class TestBlueZObex(dbusmock.DBusTestCase):
             transfer = dbus.Interface(obj, 'org.bluez.obex.transfer1.Mock')
 
             Path(transfer_filename).write_bytes(
-                b'BEGIN:VCARD\r\n' +
-                b'VERSION:3.0\r\n' +
-                b'FN:Forrest Gump\r\n' +
-                b'TEL;TYPE=WORK,VOICE:(111) 555-1212\r\n' +
-                b'TEL;TYPE=HOME,VOICE:(404) 555-1212\r\n' +
-                b'EMAIL;TYPE=PREF,INTERNET:forrestgump@example.com\r\n' +
-                b'EMAIL:test@example.com\r\n' +
-                b'URL;TYPE=HOME:http://example.com/\r\n' +
-                b'URL:http://forest.com/\r\n' +
-                b'URL:https://test.com/\r\n' +
+                b'BEGIN:VCARD\r\n'
+                b'VERSION:3.0\r\n'
+                b'FN:Forrest Gump\r\n'
+                b'TEL;TYPE=WORK,VOICE:(111) 555-1212\r\n'
+                b'TEL;TYPE=HOME,VOICE:(404) 555-1212\r\n'
+                b'EMAIL;TYPE=PREF,INTERNET:forrestgump@example.com\r\n'
+                b'EMAIL:test@example.com\r\n'
+                b'URL;TYPE=HOME:http://example.com/\r\n'
+                b'URL:http://forest.com/\r\n'
+                b'URL:https://test.com/\r\n'
                 b'END:VCARD\r\n'
             )
 
