@@ -1,5 +1,3 @@
-#!/usr/bin/python3
-
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
 # Software Foundation; either version 3 of the License, or (at your option) any
@@ -25,9 +23,9 @@ import dbus
 
 import dbusmock
 
-
 tracemalloc.start(25)
 have_upower = shutil.which('upower')
+have_gdbus = shutil.which('gdbus')
 
 
 class TestCLI(dbusmock.DBusTestCase):
@@ -55,11 +53,15 @@ class TestCLI(dbusmock.DBusTestCase):
 
     def start_mock(self, args, wait_name, wait_path, wait_system=False):
         # pylint: disable=consider-using-with
-        self.p_mock = subprocess.Popen([sys.executable, '-m', 'dbusmock'] + args,
+        self.p_mock = subprocess.Popen([sys.executable, '-m', 'dbusmock', *args],
                                        stdout=subprocess.PIPE,
                                        universal_newlines=True)
         self.wait_for_bus_object(wait_name, wait_path, wait_system)
 
+    def start_mock_process(self, args):
+        return subprocess.check_output([sys.executable, '-m', 'dbusmock', *args],
+                                       universal_newlines=True)
+
     def test_session_bus(self):
         self.start_mock(['com.example.Test', '/', 'TestIface'],
                         'com.example.Test', '/')
@@ -144,6 +146,27 @@ class TestCLI(dbusmock.DBusTestCase):
         self.assertEqual(err.returncode, 2)
         self.assertEqual(err.output, 'JSON parameters must be a dictionary\n')
 
+    @unittest.skipIf(not have_upower, 'No upower installed')
+    def test_template_upower_exec(self):
+        out = self.start_mock_process(
+            ['-t', 'upower', '--exec', 'upower', '--dump'])
+        self.assertRegex(out, r'on-battery:\s+no')
+        self.assertRegex(out, r'daemon-version:\s+0\.99')
+
+    @unittest.skipIf(not have_gdbus, 'No gdbus installed')
+    def test_manual_upower_exec(self):
+        out = self.start_mock_process(
+            ['--system',
+             'org.freedesktop.UPower',
+             '/org/freedesktop/UPower',
+             'org.freedesktop.UPower',
+             '--exec',
+             'gdbus', 'introspect', '--system',
+             '--dest', 'org.freedesktop.UPower',
+             '--object-path', '/org/freedesktop/UPower'])
+        self.assertRegex(out, r'AddMethod\(')
+        self.assertRegex(out, r'AddMethods\(')
+
     def test_template_local(self):
         with tempfile.NamedTemporaryFile(prefix='answer_', suffix='.py') as my_template:
             my_template.write(b'''import dbus
