@@ -1,5 +1,3 @@
-#!/usr/bin/python3
-
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
 # Software Foundation; either version 3 of the License, or (at your option) any
@@ -21,6 +19,7 @@ import unittest
 from pathlib import Path
 
 import dbus
+
 import dbusmock
 
 tracemalloc.start(25)
@@ -56,15 +55,15 @@ class TestLogind(dbusmock.DBusTestCase):
         cmd = ['loginctl']
         if self.version >= '209':
             cmd.append('--no-legend')
-        out = subprocess.check_output(cmd + ['list-sessions'],
+        out = subprocess.check_output([*cmd, 'list-sessions'],
                                       universal_newlines=True)
         self.assertEqual(out, '')
 
-        out = subprocess.check_output(cmd + ['list-seats'],
+        out = subprocess.check_output([*cmd, 'list-seats'],
                                       universal_newlines=True)
         self.assertEqual(out, '')
 
-        out = subprocess.check_output(cmd + ['list-users'],
+        out = subprocess.check_output([*cmd, 'list-users'],
                                       universal_newlines=True)
         self.assertEqual(out, '')
 
