@@ -1,5 +1,3 @@
-#!/usr/bin/python3
-
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
 # Software Foundation; either version 3 of the License, or (at your option) any
@@ -17,23 +15,26 @@ import re
 import shutil
 import subprocess
 import sys
-import unittest
 import tracemalloc
+import unittest
 
-from gi.repository import GLib
 import dbus
 import dbus.mainloop.glib
+from gi.repository import GLib
 
 import dbusmock
-
-from dbusmock.templates.networkmanager import DeviceState
-from dbusmock.templates.networkmanager import NM80211ApSecurityFlags
-from dbusmock.templates.networkmanager import InfrastructureMode
-from dbusmock.templates.networkmanager import NMActiveConnectionState
-from dbusmock.templates.networkmanager import NMState
-from dbusmock.templates.networkmanager import NMConnectivityState
-from dbusmock.templates.networkmanager import (CSETTINGS_IFACE, MANAGER_IFACE,
-                                               SETTINGS_OBJ, SETTINGS_IFACE)
+from dbusmock.templates.networkmanager import (
+    CSETTINGS_IFACE,
+    MANAGER_IFACE,
+    SETTINGS_IFACE,
+    SETTINGS_OBJ,
+    DeviceState,
+    InfrastructureMode,
+    NM80211ApSecurityFlags,
+    NMActiveConnectionState,
+    NMConnectivityState,
+    NMState,
+)
 
 tracemalloc.start(25)
 dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
@@ -306,7 +307,7 @@ class TestNetworkManager(dbusmock.DBusTestCase):
                 'uuid': uuid,
                 'type': '802-11-wireless'}, signature='sv'),
             '802-11-wireless': dbus.Dictionary({
-                'ssid': dbus.ByteArray('The_SSID'.encode('UTF-8'))}, signature='sv')
+                'ssid': dbus.ByteArray(b'The_SSID')}, signature='sv')
         }, signature='sa{sv}')
         con1 = self.settings.AddConnection(settings)
 
@@ -337,7 +338,7 @@ class TestNetworkManager(dbusmock.DBusTestCase):
                 'uuid': uuid,
                 'type': '802-11-wireless'}, signature='sv'),
             '802-11-wireless': dbus.Dictionary({
-                'ssid': dbus.ByteArray('The_SSID'.encode('UTF-8'))}, signature='sv')
+                'ssid': dbus.ByteArray(b'The_SSID')}, signature='sv')
         }, signature='sa{sv}')
 
         con1 = self.settings.AddConnection(settings)
@@ -553,7 +554,7 @@ class TestNetworkManager(dbusmock.DBusTestCase):
                 'uuid': uuid,
                 'type': '802-11-wireless'}, signature='sv'),
             '802-11-wireless': dbus.Dictionary({
-                'ssid': dbus.ByteArray('The_SSID'.encode('UTF-8'))}, signature='sv')
+                'ssid': dbus.ByteArray(b'The_SSID')}, signature='sv')
         }, signature='sa{sv}')
         connectionPath = self.settings.AddConnection(settings)
         self.assertEqual(self.settings.GetConnectionByUuid(uuid), connectionPath)
