@@ -1,5 +1,3 @@
-#!/usr/bin/python3
-
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
 # Software Foundation; either version 3 of the License, or (at your option) any
@@ -18,8 +16,8 @@ import shutil
 import subprocess
 import sys
 import time
-import unittest
 import tracemalloc
+import unittest
 
 import dbus
 
@@ -160,9 +158,9 @@ class TestUPower(dbusmock.DBusTestCase):
         # defines the properties which are defined
         self.assertEqual(
             set(props.keys()),
-            set(['Type', 'State', 'Percentage', 'Energy', 'EnergyFull',
-                 'EnergyRate', 'TimeToEmpty', 'TimeToFull', 'IsPresent',
-                 'IconName', 'WarningLevel']))
+            {'Type', 'State', 'Percentage', 'Energy', 'EnergyFull',
+             'EnergyRate', 'TimeToEmpty', 'TimeToFull', 'IsPresent',
+             'IconName', 'WarningLevel'})
 
         # not set up by default, so should not present
         self.assertEqual(props['IsPresent'], False)
